@@ -7,19 +7,24 @@ import textwrap
 import io
 import distutils.errors
 import itertools
+import stat
 
-from setuptools.extern import six
-from setuptools.extern.six.moves import map, filter, filterfalse
+import six
+from six.moves import map, filter, filterfalse
 
 try:
     from setuptools.lib2to3_ex import Mixin2to3
 except ImportError:
-    class Mixin2to3:
 
+    class Mixin2to3:
         def run_2to3(self, files, doctests=True):
             "do nothing"
 
 
+def make_writable(target):
+    os.chmod(target, os.stat(target).st_mode | stat.S_IWRITE)
+
+
 class build_py(orig.build_py, Mixin2to3):
     """Enhanced 'build_py' command that includes data files with packages
 
@@ -121,6 +126,7 @@ class build_py(orig.build_py, Mixin2to3):
                 self.mkpath(os.path.dirname(target))
                 srcfile = os.path.join(src_dir, filename)
                 outf, copied = self.copy_file(srcfile, target)
+                make_writable(target)
                 srcfile = os.path.abspath(srcfile)
                 if (copied and
                         srcfile in self.distribution.convert_2to3_doctests):
@@ -219,7 +225,7 @@ class build_py(orig.build_py, Mixin2to3):
     @staticmethod
     def _get_platform_patterns(spec, package, src_dir):
         """
-        yield platfrom-specific path patterns (suitable for glob
+        yield platform-specific path patterns (suitable for glob
         or fn_match) from a glob-based spec (such as
         self.package_data or self.exclude_package_data)
         matching package in src_dir.
